@@ -52,6 +52,15 @@ gboolean gs_file_sync_data (GFile          *file,
                             GCancellable   *cancellable,
                             GError        **error);
 
+char * gsystem_fileutil_gen_tmp_name (const char *prefix,
+                                      const char *suffix);
+
+gboolean gs_file_create (GFile          *file,
+                         int             mode,
+                         GOutputStream **out_stream,
+                         GCancellable   *cancellable,
+                         GError        **error);
+
 gboolean gs_file_linkcopy (GFile          *src,
                            GFile          *dest,
                            GFileCopyFlags  flags,
@@ -98,6 +107,10 @@ gchar *gs_file_load_contents_utf8 (GFile         *file,
                                    GCancellable  *cancellable,
                                    GError       **error);
 
+gchar *gs_file_get_relpath (GFile *one,
+                            GFile *two);
+
+GFile * gs_file_realpath (GFile *file);
 
 G_END_DECLS
 
