@@ -20,9 +20,6 @@
  * Author: Colin Walters <walters@verbum.org>
  */
 
-/* for mkdtemp */
-#define _GNU_SOURCE
-
 #include "config.h"
 
 #include "ostree.h"
@@ -1120,14 +1117,6 @@ ostree_file_header_parse (GVariant         *metadata,
     {
       g_file_info_set_attribute_byte_string (ret_file_info, "standard::symlink-target", symlink_target);
     }
-  else if (S_ISCHR (mode) || S_ISBLK (mode))
-    {
-      g_file_info_set_attribute_uint32 (ret_file_info, "unix::rdev", rdev);
-    }
-  else if (S_ISFIFO (mode))
-    {
-      ;
-    }
   else
     {
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
@@ -1181,14 +1170,6 @@ ostree_zlib_file_header_parse (GVariant         *metadata,
     {
       g_file_info_set_attribute_byte_string (ret_file_info, "standard::symlink-target", symlink_target);
     }
-  else if (S_ISCHR (mode) || S_ISBLK (mode))
-    {
-      g_file_info_set_attribute_uint32 (ret_file_info, "unix::rdev", rdev);
-    }
-  else if (S_ISFIFO (mode))
-    {
-      ;
-    }
   else
     {
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
@@ -1214,7 +1195,7 @@ ostree_create_file_from_input (GFile            *dest_file,
   gboolean ret = FALSE;
   const char *dest_path;
   guint32 uid, gid, mode;
-  gs_unref_object GFileOutputStream *out = NULL;
+  gs_unref_object GOutputStream *out = NULL;
 
   if (g_cancellable_set_error_if_cancelled (cancellable, error))
     return FALSE;
@@ -1239,8 +1220,8 @@ ostree_create_file_from_input (GFile            *dest_file,
     }
   else if (S_ISREG (mode))
     {
-      out = g_file_create (dest_file, 0, cancellable, error);
-      if (!out)
+      if (!gs_file_create (dest_file, mode, &out,
+                           cancellable, error))
         goto out;
 
       if (input)
@@ -1262,23 +1243,6 @@ ostree_create_file_from_input (GFile            *dest_file,
           goto out;
         }
     }
-  else if (S_ISCHR (mode) || S_ISBLK (mode))
-    {
-      guint32 dev = g_file_info_get_attribute_uint32 (finfo, "unix::rdev");
-      if (mknod (dest_path, mode, dev) < 0)
-        {
-          ot_util_set_error_from_errno (error, errno);
-          goto out;
-        }
-    }
-  else if (S_ISFIFO (mode))
-    {
-      if (mkfifo (dest_path, mode) < 0)
-        {
-          ot_util_set_error_from_errno (error, errno);
-          goto out;
-        }
-    }
   else
     {
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
@@ -1299,16 +1263,6 @@ ostree_create_file_from_input (GFile            *dest_file,
         }
     }
 
-  if (!S_ISLNK (mode))
-    {
-      if (chmod (dest_path, mode) < 0)
-        {
-          ot_util_set_error_from_errno (error, errno);
-          g_prefix_error (error, "chmod(%u) failed: ", mode);
-          goto out;
-        }
-    }
-
   if (xattrs != NULL)
     {
       if (!ostree_set_xattrs (dest_file, xattrs, cancellable, error))
@@ -1324,57 +1278,6 @@ ostree_create_file_from_input (GFile            *dest_file,
   return ret;
 }
 
-static const char *
-get_default_tmp_prefix (void)
-{
-  static char *tmpprefix = NULL;
-
-  if (g_once_init_enter (&tmpprefix))
-    {
-      const char *prgname = g_get_prgname ();
-      const char *p;
-      char *prefix;
-
-      p = strrchr (prgname, '/');
-      if (p)
-        prgname = p + 1;
-
-      prefix = g_strdup_printf ("tmp-%s%u-", prgname, getuid ());
-      
-      g_once_init_leave (&tmpprefix, prefix);
-    }
-
-  return tmpprefix;
-}
-
-static char *
-create_tmp_name (const char *dirpath,
-                 const char *prefix,
-                 const char *suffix)
-{
-  static const char table[] = "ABCEDEFGHIJKLMNOPQRSTUVWXYZabcedefghijklmnopqrstuvwxyz0123456789";
-  GString *tmp_name = NULL;
-  guint i;
-
-  if (!prefix)
-    prefix = get_default_tmp_prefix ();
-  if (!suffix)
-    suffix = "tmp";
-
-  tmp_name = g_string_new (dirpath);
-  g_string_append_c (tmp_name, '/');
-  g_string_append (tmp_name, prefix);
-  for (i = 0; i < 8; i++)
-    {
-      int offset = g_random_int_range (0, sizeof (table) - 1);
-      g_string_append_c (tmp_name, (guint8)table[offset]);
-    }
-  g_string_append_c (tmp_name, '.');
-  g_string_append (tmp_name, suffix);
-
-  return g_string_free (tmp_name, FALSE);
-}
-
 gboolean
 ostree_create_temp_file_from_input (GFile            *dir,
                                     const char       *prefix,
@@ -1400,8 +1303,7 @@ ostree_create_temp_file_from_input (GFile            *dir,
       if (g_cancellable_set_error_if_cancelled (cancellable, error))
         goto out;
 
-      possible_name = create_tmp_name (gs_file_get_path_cached (dir),
-                                       prefix, suffix);
+      possible_name = gsystem_fileutil_gen_tmp_name (prefix, suffix);
       g_clear_object (&possible_file);
       possible_file = g_file_get_child (dir, possible_name);
       
@@ -1690,11 +1592,7 @@ ostree_validate_structureof_file_mode (guint32            mode,
 {
   gboolean ret = FALSE;
 
-  if (!(S_ISREG (mode)
-        || S_ISLNK (mode)
-        || S_ISCHR (mode)
-        || S_ISBLK (mode)
-        || S_ISFIFO (mode)))
+  if (!(S_ISREG (mode) || S_ISLNK (mode)))
     {
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
                    "Invalid file metadata mode %u; not a valid file type", mode);
