@@ -20,8 +20,7 @@
  * Author: Colin Walters <walters@verbum.org>
  */
 
-#ifndef _OSTREE_REPO
-#define _OSTREE_REPO
+#pragma once
 
 #include "ostree-core.h"
 #include "ostree-types.h"
@@ -78,6 +77,7 @@ GFile *       ostree_repo_get_file_object_path (OstreeRepo   *self,
 
 gboolean      ostree_repo_prepare_transaction (OstreeRepo     *self,
                                                gboolean        enable_commit_hardlink_scan,
+                                               gboolean       *out_transaction_resume,
                                                GCancellable   *cancellable,
                                                GError        **error);
 
@@ -317,6 +317,47 @@ gboolean ostree_repo_list_objects (OstreeRepo                  *self,
                                    GCancellable                *cancellable,
                                    GError                     **error);
 
+GHashTable *ostree_repo_traverse_new_reachable (void);
+
+gboolean ostree_repo_traverse_dirtree (OstreeRepo         *repo,
+                                       const char         *commit_checksum,
+                                       GHashTable         *inout_reachable,
+                                       GCancellable       *cancellable,
+                                       GError            **error);
+
+gboolean ostree_repo_traverse_commit (OstreeRepo         *repo,
+                                      const char         *commit_checksum,
+                                      int                 maxdepth,
+                                      GHashTable         *inout_reachable,
+                                      GCancellable       *cancellable,
+                                      GError            **error);
+
+typedef enum {
+  OSTREE_REPO_PRUNE_FLAGS_NONE,
+  OSTREE_REPO_PRUNE_FLAGS_NO_PRUNE,
+  OSTREE_REPO_PRUNE_FLAGS_REFS_ONLY
+} OstreeRepoPruneFlags;
+
+gboolean ostree_repo_prune (OstreeRepo        *repo,
+                            OstreeRepoPruneFlags   flags,
+                            gint               depth,
+                            gint              *out_objects_total,
+                            gint              *out_objects_pruned,
+                            guint64           *out_pruned_object_size_total,
+                            GCancellable      *cancellable,
+                            GError           **error);
+
+typedef enum {
+  OSTREE_REPO_PULL_FLAGS_NONE,
+  OSTREE_REPO_PULL_FLAGS_RELATED
+} OstreeRepoPullFlags;
+
+gboolean ostree_repo_pull (OstreeRepo             *repo,
+                           const char             *remote_name,
+                           char                  **refs_to_fetch,
+                           OstreeRepoPullFlags     flags,
+                           GCancellable           *cancellable,
+                           GError                **error);
+
 G_END_DECLS
 
-#endif /* _OSTREE_REPO */
