@@ -25,9 +25,6 @@
 #include "ot-builtins.h"
 #include "ostree.h"
 
-#include <glib/gi18n.h>
-#include <glib/gprintf.h>
-
 static gboolean quiet;
 static gboolean delete;
 
@@ -58,7 +55,7 @@ fsck_reachable_objects_from_commits (OtFsckData            *data,
   gs_free guchar *computed_csum = NULL;
   gs_free char *tmp_checksum = NULL;
 
-  reachable_objects = ostree_traverse_new_reachable ();
+  reachable_objects = ostree_repo_traverse_new_reachable ();
 
   g_hash_table_iter_init (&hash_iter, commits);
   while (g_hash_table_iter_next (&hash_iter, &key, &value))
@@ -71,8 +68,8 @@ fsck_reachable_objects_from_commits (OtFsckData            *data,
 
       g_assert (objtype == OSTREE_OBJECT_TYPE_COMMIT);
 
-      if (!ostree_traverse_commit (data->repo, checksum, 0, reachable_objects,
-                                   cancellable, error))
+      if (!ostree_repo_traverse_commit (data->repo, checksum, 0, reachable_objects,
+                                        cancellable, error))
         goto out;
     }
 
@@ -178,12 +175,11 @@ fsck_reachable_objects_from_commits (OtFsckData            *data,
 }
 
 gboolean
-ostree_builtin_fsck (int argc, char **argv, GFile *repo_path, GError **error)
+ostree_builtin_fsck (int argc, char **argv, GFile *repo_path, GCancellable *cancellable, GError **error)
 {
+  gboolean ret = FALSE;
   GOptionContext *context;
   OtFsckData data;
-  gboolean ret = FALSE;
-  GCancellable *cancellable = NULL;
   GHashTableIter hash_iter;
   gpointer key, value;
   gs_unref_object OstreeRepo *repo = NULL;
