@@ -25,8 +25,6 @@
 #include "ot-builtins.h"
 #include "ostree.h"
 
-#include <glib/gi18n.h>
-
 static gboolean print_related;
 static char* print_variant_type;
 static char* print_metadata_key;
@@ -196,7 +194,7 @@ do_print_metadata_key (OstreeRepo  *repo,
 }
 
 gboolean
-ostree_builtin_show (int argc, char **argv, GFile *repo_path, GError **error)
+ostree_builtin_show (int argc, char **argv, GFile *repo_path, GCancellable *cancellable, GError **error)
 {
   GOptionContext *context;
   gboolean ret = FALSE;
